@@ -14,9 +14,15 @@ import aws_cdk.aws_codepipeline
 import aws_cdk.aws_codepipeline_actions
 import aws_cdk.aws_events
 import aws_cdk.aws_iam
+import aws_cdk.cloud_assembly_schema
 import aws_cdk.core
 import aws_cdk.cx_api
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/app-delivery", "1.34.1", __name__[0:-6], "app-delivery@1.34.1.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
